@@ -146,6 +146,9 @@ FAILEDOPERATION_NOTALLOW = 'FailedOperation.NotAllow'
 # 该Notebook实例不支持保存镜像，如果您使用的是自定义镜像请重启Notebook实例后再执行保存操作
 FAILEDOPERATION_NOTSUPPORTEDTOCREATEIMAGE = 'FailedOperation.NotSupportedToCreateImage'
 
+# 未找到Notebook实例相关容器，无法生成访问地址。
+FAILEDOPERATION_PODIPNOTFOUND = 'FailedOperation.PodIpNotFound'
+
 # 请求正在处理中，请稍后再试。
 FAILEDOPERATION_PROCESSING = 'FailedOperation.Processing'
 
@@ -242,6 +245,9 @@ INTERNALERROR_QUERYBINDINGTAGSFAILED = 'InternalError.QueryBindingTagsFailed'
 # 获取HDFS存储信息失败。
 INTERNALERROR_QUERYHDFSINFOFAILED = 'InternalError.QueryHDFSInfoFailed'
 
+# 询价失败
+INTERNALERROR_QUERYPRICEFAILED = 'InternalError.QueryPriceFailed'
+
 # 查询预付费资源组详情失败。
 INTERNALERROR_QUERYRESOURCEGROUPFAILED = 'InternalError.QueryResourceGroupFailed'
 
@@ -257,6 +263,9 @@ INTERNALERROR_QUERYSUBNETINFOFAILED = 'InternalError.QuerySubnetInfoFailed'
 # 查询用户临时秘钥失败
 INTERNALERROR_QUERYUSERTMPCREDENTIALFAILED = 'InternalError.QueryUserTMPCredentialFailed'
 
+# 查询vpc信息失败
+INTERNALERROR_QUERYVPCINFOFAILED = 'InternalError.QueryVPCInfoFailed'
+
 # 停止任务失败。
 INTERNALERROR_STOPJOBINSTANCEFAILED = 'InternalError.StopJobInstanceFailed'
 
@@ -287,6 +296,9 @@ INVALIDPARAMETER_VALIDATEERROR = 'InvalidParameter.ValidateError'
 # 参数取值错误。
 INVALIDPARAMETERVALUE = 'InvalidParameterValue'
 
+# 当前任务选择了平台CFS的内置代码，且未正确配置/opt/ml/output/data输出路径，任务无法提交
+INVALIDPARAMETERVALUE_AIMARKETOUTPUTCONFIGEMPTY = 'InvalidParameterValue.AIMarketOutputConfigEmpty'
+
 # AI市场公共算法版本Id不存在
 INVALIDPARAMETERVALUE_AIMARKETPUBLICALGOVERSIONNOTEXIST = 'InvalidParameterValue.AIMarketPublicAlgoVersionNotExist'
 
@@ -332,12 +344,18 @@ INVALIDPARAMETERVALUE_DCDATASETTYPE = 'InvalidParameterValue.DCDatasetType'
 # 不支持的过滤参数。
 INVALIDPARAMETERVALUE_DCFILTERVALUES = 'InvalidParameterValue.DCFilterValues'
 
+# 数据集不存在
+INVALIDPARAMETERVALUE_DATASETNOTEXIST = 'InvalidParameterValue.DatasetNotExist'
+
 # 数据集数量超过限制。
 INVALIDPARAMETERVALUE_DATASETNUMLIMITEXCEEDED = 'InvalidParameterValue.DatasetNumLimitExceeded'
 
 # 实例名称冲突，请更换名称后重试。
 INVALIDPARAMETERVALUE_DUPLICATENAME = 'InvalidParameterValue.DuplicateName'
 
+# 文件系统路径访问权限受限
+INVALIDPARAMETERVALUE_FSPATHINACCESSIBLE = 'InvalidParameterValue.FSPathInaccessible'
+
 # 训练框架对应的版本不支持，请阅读文档查看TIONE目前支持的框架和版本。
 INVALIDPARAMETERVALUE_FRAMEWORKVERSIONNOTSUPPORT = 'InvalidParameterValue.FrameworkVersionNotSupport'
 
@@ -380,6 +398,12 @@ INVALIDPARAMETERVALUE_NOTALLOWEDTOCREATENOTEBOOKWITHBAREMETALRESOURCEGROUP = 'In
 # 分页查询limit超出限制
 INVALIDPARAMETERVALUE_PAGELIMITEXCEEDED = 'InvalidParameterValue.PageLimitExceeded'
 
+# 参数长度超过限制
+INVALIDPARAMETERVALUE_PARAMLENGTHEXCEEDLIMIT = 'InvalidParameterValue.ParamLengthExceedLimit'
+
+# 查询vpc信息失败
+INVALIDPARAMETERVALUE_QUERYVPCINFOFAILED = 'InvalidParameterValue.QueryVPCInfoFailed'
+
 # RDMA配置不合法
 INVALIDPARAMETERVALUE_RDMACONFIGILLEGAL = 'InvalidParameterValue.RDMAConfigIllegal'
 
@@ -422,6 +446,9 @@ OPERATIONDENIED_BILLINGEXCEPTION = 'OperationDenied.BillingException'
 # 按量计费资源售罄。
 OPERATIONDENIED_BILLINGSTATUSRESOURCEINSUFFICIENT = 'OperationDenied.BillingStatusResourceInsufficient'
 
+# vpc 和 子网 禁止修改
+OPERATIONDENIED_FORBIDMODIFYVPCANDSUBNET = 'OperationDenied.ForbidModifyVpcAndSubnet'
+
 # IP不合法。
 OPERATIONDENIED_IPILLEGAL = 'OperationDenied.IpIllegal'
 
@@ -443,6 +470,9 @@ OPERATIONDENIED_RESOURCEGROUPINSUFFICIENT = 'OperationDenied.ResourceGroupInsuff
 # 子网不合法。
 OPERATIONDENIED_SUBNETILLEGAL = 'OperationDenied.SubnetIllegal'
 
+# 太极应用组存量资源不足，不满足训练要求
+OPERATIONDENIED_TAIJIAPPLICATIONGROUPINSUFFICIENT = 'OperationDenied.TAIJIApplicationGroupInsufficient'
+
 # 白名单免费配额不足。
 OPERATIONDENIED_WHITELISTQUOTAEXCEED = 'OperationDenied.WhitelistQuotaExceed'
 
@@ -455,9 +485,15 @@ RESOURCEINSUFFICIENT = 'ResourceInsufficient'
 # 资源不存在。
 RESOURCENOTFOUND = 'ResourceNotFound'
 
+# 文件系统不存在
+RESOURCENOTFOUND_CFSNOTFOUND = 'ResourceNotFound.CfsNotFound'
+
 # 没有该模型。
 RESOURCENOTFOUND_NOMODEL = 'ResourceNotFound.NoModel'
 
+# vpc不存在
+RESOURCENOTFOUND_VPCNOTFOUND = 'ResourceNotFound.VPCNotFound'
+
 # 资源不可用。
 RESOURCEUNAVAILABLE = 'ResourceUnavailable'
 
